import unittest

import os
import configparser

import pytest
import pyotp
from jugaad_trader import Zerodha, Console

config = configparser.ConfigParser()
try:
    home_folder = os.path.expanduser('~')
    config.read(os.path.join(home_folder, '.config', 'jtrader', '.zcred'))
    config['CREDENTIALS']
except:
    Exception("Credentials not found")

creds = config['CREDENTIALS']
otp_gen = pyotp.TOTP(creds['twofa'])
z = Zerodha(creds['user_id'],
            creds['password'],
            otp_gen.now())

c = Console(z)
def test_console_login():
    # Should raise exception if not logged in to Zerodha
    with pytest.raises(Exception):
        c.login()
    # Should login normally
    z.twofa = otp_gen.now()
    z.login()
    assert c.login()

def dry_tester(v):
    assert v['state'] in ['PENDING', 'SUCCESS']
    assert 'result' in v

def test_dashboard():
    v = c.dashboard()
    dry_tester(v)

def test_account_values():
    v = c.account_values()
    dry_tester(v)

def test_positions():
    v = c.positions(date="2021-07-19", segment="FO")
    dry_tester(v)

def test_exposure():
    v = c.exposure(segment="FO", date="2021-07-09")
    dry_tester(v)

def test_portfolio():
    v = c.portfolio(date="2021-07-11")
    dry_tester(v)

def test_tradebook():
    v = c.tradebook(segment="EQ",
                    from_date="2021-06-11",
                    to_date="2021-07-11",
                    page=1)
    dry_tester(v)
    v = c.tradebook(segment="FO",
                    from_date="2021-06-11",
                    to_date="2021-07-11",
                    page=1)
    dry_tester(v)

def test_pnl_and_summary():
    v = c.pnl(segment="EQ",
              from_date="2021-06-11",
              to_date="2021-07-11",
              view_type="combined",
              sort_by="tradingsymbol",
              sort_desc="false",
              page="1")
    dry_tester(v)
    v = c.pnl(segment="FO",
              from_date="2021-06-11",
              to_date="2021-07-11",
              view_type="combined",
              sort_by="tradingsymbol",
              sort_desc="false",
              page="1")

    dry_tester(v)
    v = c.pnl_summary(segment="EQ",
              from_date="2021-06-11",
              to_date="2021-07-11",
              view_type="combined",
              sort_by="tradingsymbol",
              sort_desc="false",
              page="1")
    dry_tester(v)
    v = c.pnl_summary(segment="FO",
              from_date="2021-06-11",
              to_date="2021-07-11",
              view_type="combined",
              sort_by="tradingsymbol",
              sort_desc="false",
              page="1")

    dry_tester(v)


def test_tax_pnl():
    v = c.tax_pnl(fy="2020_2021",
                  from_quarter="Q1",
                  to_quarter="Q2")
    dry_tester(v)

def test_fund_balance():
    v = c.fund_balance()
    dry_tester(v)


def test_ledger():
    v = c.ledger(segment="EQ",
                 from_date="2021-07-04",
                 to_date="2021-07-11",
                 page="1")
    dry_tester(v)



import os
import configparser
import pickle
import click
from .zcli import zerodha
from .ucli import upstox

cli = click.Group(commands={
                            "zerodha": zerodha,
                            "upstox": upstox
                            })



if __name__ == "__main__":
    cli()



import unittest
import os
import configparser
import pickle
import datetime

import click
import pyotp
from jugaad_trader import Zerodha
from jugaad_trader.util import CLI_NAME
from loguru import logger

app_dir = click.get_app_dir(CLI_NAME)
config = configparser.ConfigParser()
try:
    home_folder = os.path.expanduser('~')
    config.read(os.path.join(home_folder, '.config', 'jtrader', '.zcred'))
    config['CREDENTIALS']
except:
    Exception("Credentials not found")


class TestZerodhaLogin(unittest.TestCase):
    creds = config['CREDENTIALS']
    otp_gen = pyotp.TOTP(creds['twofa'])
    

    z = Zerodha(creds['user_id'],
                creds['password'],
                otp_gen.now())
    
    def seq1_login_step1_valid_creds(self):
        self.step1_result = self.z.login_step1()
        self.assertEqual(self.step1_result['status'], 'success')
    


    def seq2_login_step2_valid_creds(self):
        logger.info(self.step1_result)
        j = self.z.login_step2(self.step1_result)
        logger.info(j)
        self.assertEqual(j['status'], 'success')
        self.assertIn('enctoken', self.z.r.cookies)

    def seq3_login_valid_creds(self):
        j = self.z.login()
        self.assertEqual(j['status'], 'success')
    
    def seq4_login_invalid_pass(self):
        self.z.password = "somerandompassword"
        with self.assertRaises(Exception):
            self.z.login()
        self.z.password = self.creds['password']
    
    def seq5_login_invalid_2fa(self):
        self.z.twofa = "939344"
        with self.assertRaises(Exception):
            self.z.login()
        self.z.password = self.creds['twofa']



    def _steps(self):
        for name in dir(self): # dir() result is implicitly sorted
            if name.startswith("seq"):
                yield name, getattr(self, name)

    def test_steps(self):
        click.echo("test-sequence(", nl=False)
        for i, (_, step) in enumerate(self._steps()):
            try:
                step()
                click.echo("{}".format(i+1), nl=False)
            except Exception as e:
                self.fail("{} failed ({}: {})".format(step, type(e), e))
        click.echo(")", nl=False)
    
    def test_login_step1_invalid_creds(self):
        z = Zerodha("randomcreds", "randomstring123324", "2231212")
        step1_result = z.login_step1()
        self.assertEqual(step1_result['status'], 'error')
        z.close()
    
    def test_ltp(self):
        self.z.twofa = self.otp_gen.now()
        self.z.login()
        l = self.z.ltp(408065)
        self.assertIn('408065', l)
    
    def test_history(self):
        self.z.twofa = self.otp_gen.now()
        self.z.login()
        token = '128083204'
        from_date = (datetime.datetime.now() - datetime.timedelta(days=20)).date()
        to_date = datetime.datetime.now().date()
        logger.info(f"{token}, {from_date} {to_date}")
        data  = self.z.historical_data(token, from_date, to_date, interval='day')

        assert len(data) > 5
        
    def tearDown(self):
        self.z.close()



def test_instrument():
    z = Zerodha("randomcreds", "randomstring123324", "2231212")
    instr = z.instruments()
    assert len(instr) > 100
    instr = z.instruments("NSE")
    assert len(instr) > 100
    
if __name__=="__main__":
    
    unittest.main()




import csv
import json
import hashlib
import logging
import datetime
import time
import operator
import json
import configparser
import os
import pickle


import requests
import click
from six.moves.urllib.parse import urljoin


from kiteconnect import KiteConnect, KiteTicker
import kiteconnect.exceptions as ex
from bs4 import BeautifulSoup

from jugaad_trader.util import CLI_NAME


log = logging.getLogger(__name__)

base_url = "https://kite.zerodha.com"
login_url = "https://kite.zerodha.com/api/login"
twofa_url = "https://kite.zerodha.com/api/twofa"
instruments_url = "https://api.kite.trade/instruments"
class Zerodha(KiteConnect):
    """
        TO DO:
        instruments - Deviation from KiteConnect
        
        
    """
    _default_root_uri = "https://kite.zerodha.com"
    def __init__(self, user_id=None, password=None, twofa=None):
    
        self.user_id = user_id
        self.password = password
        self.twofa = twofa
    
        super().__init__(api_key="")
        self.s = self.reqsession = requests.Session()
        headers = {"user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.164 Safari/537.36",
            "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
            "accept-language": "en-GB,en-US;q=0.9,en;q=0.8",
                    }
        self.reqsession.headers.update(headers)
        self.chunkjs = {}
        self.url_patch = '/oms'
        # self._routes["user.profile"] = "/user/profile/full"

    def set_access_token(self):
        self.load_session()

    def load_session(self, path=None):
        
        if path==None:
            path = os.path.join(click.get_app_dir(CLI_NAME), ".zsession")
        try:
            with open(path, "rb") as fp:
                self.reqsession = pickle.load(fp)
        except FileNotFoundError:
            raise FileNotFoundError("\n\nCould not find the session, Please start a session using \n\n$ jtrader zerodha startsession")
        self.enc_token = self.reqsession.cookies['enctoken']
        self.user_id = self.reqsession.cookies['user_id']

    def load_creds(self, path=None):
        if path==None:
            path = os.path.join(click.get_app_dir(CLI_NAME), ".zcred")
        config = configparser.ConfigParser()
        try:
            config.read(path)
        except FileNotFoundError:
            raise FileNotFoundError("\n\nCould not find the credentials, Please save the credentials using \n\n$ jtrader zerodha savecreds")
        creds = config['CREDENTIALS']
        self.user_id = creds['user_id']
        self.password = creds['password']
        self.twofa = creds['twofa']

    def _user_agent(self):
        return "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.164 Safari/537.36"
    
    def login_step1(self):
        self.r = self.reqsession.get(base_url)
        self.r = self.reqsession.post(login_url, data={"user_id": self.user_id, "password":self.password})
        j = json.loads(self.r.text)
        return j

    def login_step2(self, j):
        data = {"user_id": self.user_id, "request_id": j['data']["request_id"], "twofa_value": self.twofa }
        self.r = self.s.post(twofa_url, data=data)
        j = json.loads(self.r.text)
        return j


    def login(self):
        j = self.login_step1()
        if j['status'] == 'error':
            raise Exception(j['message'])
        
        j = self.login_step2(j)
        if j['status'] == 'error':
            raise Exception(j['message'])
        self.enc_token = self.r.cookies['enctoken']
        return j

    def custom_headers(self):
        h = {}
        h['authorization'] = "enctoken {}".format(self.enc_token)
        h['referer'] = 'https://kite.zerodha.com/dashboard'
        h['x-kite-version'] = '2.9.2'
        h['sec-fetch-site'] = 'same-origin'
        h['sec-fetch-mode'] = 'cors'
        h['sec-fetch-dest'] = 'empty'
        h['x-kite-userid'] = self.user_id
        return h
    
    def _request(self, route, method, url_args=None, params=None,
                 is_json=False, query_params=None):
        if url_args:
            uri = self._routes[route].format(**url_args)
        else:
            uri = self._routes[route] 

        url = urljoin(self.root, self.url_patch + uri)
        
        # prepare url query params
        if method in ["GET", "DELETE"]:
            query_params = params


        # Custom headers
        headers = self.custom_headers()

        if self.debug:
            log.debug("Request: {method} {url} {params} {headers}".format(method=method, url=url, params=params, headers=headers))

        try:
            r = self.reqsession.request(method,
                                        url,
                                        json=params if (method in ["POST", "PUT"] and is_json) else None,
                                        data=params if (method in ["POST", "PUT"] and not is_json) else None,
                                        params=query_params,
                                        headers=headers,
                                        verify=not self.disable_ssl,
                                        allow_redirects=True,
                                        timeout=self.timeout,
                                        proxies=self.proxies)
            self.r = r
        except Exception as e:
            raise e

        if self.debug:
            log.debug("Response: {code} {content}".format(code=r.status_code, content=r.content))

        # Validate the content type.
        if "json" in r.headers["content-type"]:
            try:
                data = json.loads(r.content.decode("utf8"))
            except ValueError:
                raise ex.DataException("Couldn't parse the JSON response received from the server: {content}".format(
                    content=r.content))

            # api error
            if data.get("status") == "error" or data.get("error_type"):
                # Call session hook if its registered and TokenException is raised
                if self.session_expiry_hook and r.status_code == 403 and data["error_type"] == "TokenException":
                    self.session_expiry_hook()

                # native Kite errors
                exp = getattr(ex, data.get("error_type"), ex.GeneralException)
                raise exp(data["message"], code=r.status_code)

            return data["data"]
        elif "csv" in r.headers["content-type"]:
            return r.content
        else:
            raise ex.DataException("Unknown Content-Type ({content_type}) with response: ({content})".format(
                content_type=r.headers["content-type"],
                content=r.content))
    
    def get_chunk_js(self):
        self.r = self.reqsession.get(urljoin(base_url, '/dashboard'))
        html = self.r.text
        bs = BeautifulSoup(html)
        for tag in bs.find_all("link"):
            src = tag.attrs.get("href", "")
            if "chunk" in src:
                break
        url = urljoin(base_url, tag.attrs.get("href"))
        self.r = self.reqsession.get(url)
        return self.r.text
    
    def chunk_to_json(self, js):
        start = js.find('{"months"')
        end = js.find("\')}}])")
        jtxt = js[start:end].replace('\\','')
        self.chunkjs = json.loads(jtxt)
        return self.chunkjs
    
    def instruments(self, exchange=None):
        if exchange:
            self.r = self.reqsession.get(instruments_url + "/{}".format(exchange))
        else:
            self.r = self.reqsession.get(instruments_url)
        return self._parse_instruments(self.r.text)
        
    def close(self):
        self.reqsession.close()
   
    
    def ticker(self, api_key='kitefront', enctoken=None, userid=None):
        if enctoken is not None:
            self.enctoken = self.r.cookies['enc_token']
        if userid is not None:
            self.user_id = self.user_id
        if self.user_id is None:
            raise Exception("\nCould not find the session, Please start a session using \n\n$ jtrader zerodha startsession")
        return KiteTicker(api_key=api_key, access_token=self.enc_token+'&user_id='+self.user_id, root='wss://ws.zerodha.com')
                            
class Console(Zerodha):
    """
        Experimental support for Zerodha backoffice platform Coin
    """
    _default_root_uri = "https://console.zerodha.com"
    api_key = "console" # API key for Coin
    _routes = {
        "login":"/kite/login",
        "status": "/api/user/status",
        "user_profile": "/api/user_profile/status",
        "dashboard": "/api/dashboard",
        "account_values": "/api/dashboard/account_values",
        "positions": "/api/reports/positions",
        "exposure": "/api/reports/positions/exposure",
        "portfolio": "/api/reports/holdings/portfolio",
        "tradebook": "/api/reports/tradebook",
        "pnl": "/api/reports/pnl",
        "pnl_summary": "/api/reports/pnl/summary",
        "tax_pnl": "/api/reports/taxpnl",
        "fund_balance": "https://console.zerodha.com/api/funds/balance",
        "ledger": "/api/ledger",
        "interest_statement": "/api/funds/interest_statement",
        "mandate": "/api/mandate"
    }
    def __init__(self, z):
        """
            args:
                z - Instance of Zerodha class
        """
        
        super().__init__(z.user_id, z.password, z.twofa)
        self._root = self._default_root_uri

        self.url_patch = ""
        self.reqsession = z.reqsession
        headers = {"user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.164 Safari/537.36",
            "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
            "accept-language": "en-GB,en-US;q=0.9,en;q=0.8",
                    }
        self.reqsession.headers.update(headers)
        self.console_session = "" 
        self.public_token = "" 
        self.register_functions() 
    def custom_headers(self):
        h = {}
        h['referer'] = 'https://console.zerodha.com/'
        h['x-kite-version'] = '3'
        h['sec-fetch-site'] = 'same-origin'
        h['sec-fetch-mode'] = 'cors'
        h['sec-fetch-dest'] = 'empty'
        h['user-agent'] = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.164 Safari/537.36"

        return h
    

    def login(self):
        """
            Get request to /login redirects to kite, if the Kite session is
            already active, You are redirected back to Console and logged in
            automatically            
        """
        url = self._root + self._routes["login"]
        self.r = self.reqsession.get(url) 
        if self.r.url == 'https://console.zerodha.com/dashboard':
            cookies = self.reqsession.cookies.get_dict('console.zerodha.com')
            self.console_session = cookies['session']
            return True
        else:
            raise Exception("Login failed or Kite session expired")
    
    def factory_functions(self, route, docstring=""):
        """
            All APIs used by console end up sendinga a get request with some
            data, hence creating a fatory function which will generate a
            function to send GET requests
        """
        def generic_function(**kwargs):
            return self._get(route, params=kwargs)
        generic_function.__doc__ = docstring
        return generic_function
    
    def register_functions(self):
        self.dashboard = self.factory_functions("dashboard")
        self.account_values = self.factory_functions("account_values")
        self.positions = self.factory_functions("positions")
        self.exposure = self.factory_functions("exposure")
        self.portfolio = self.factory_functions("portfolio")
        self.tradebook = self.factory_functions("tradebook")
        self.pnl = self.factory_functions("pnl")
        self.pnl_summary = self.factory_functions("pnl_summary")
        self.tax_pnl = self.factory_functions("tax_pnl")
        self.fund_balance = self.factory_functions("fund_balance")
        self.ledger = self.factory_functions("ledger")
        self.interest_statement = self.factory_functions("interest_statement")
        self.mandate = self.factory_functions("mandate")
   
if __name__=="__main__":
    pass




import asyncio
import pathlib
import ssl
import json
import uuid
import os 
import websockets
from requests import Session
import certifi
from bs4 import BeautifulSoup
import json
import configparser
import click
from jugaad_trader.util import CLI_NAME


ssl_context = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
localhost_pem = certifi.where()
ssl_context.load_verify_locations(localhost_pem)

class Upstox:
    def __init__(self, client_id="", password="", twofa=""):
        self.client_id = client_id
        self.password = password
        self.twofa = twofa
        self.loop = asyncio.get_event_loop()
        self.event_tree = {}
        headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
            "Host": "pro.upstox.com",
        }
        self.s = Session()
        self.s.headers.update(headers)
        self.keys = { 
                    "apiId": "e6bb46d9d4b16dae8cf5173e047fa10ca1d79ec48d3e9fb747d4eabad8ba5313",
                    "token": "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJVUFNUT1hQUk9NQUlOIiwiYXVkIjoiVVBTVE9YUFJPTUFJTnxXRUIiLCJzdWIiOiJHZXQgU29ja2V0IENvbm5lY3Rpb24iLCJpYXQiOjE1OTc2NjM1Njg1NjUsImV4cCI6MTYwNzY2MzU2ODU2NX0.JUUdWtrfacqDiqUGQNEeeehCGid8HpiF08f3jrI-a8o"
    }

    def notification_handler(self, packet):
        print("Notification: " + packet)
    
    def load_creds(self, path=None):
        if path==None:
            path = os.path.join(click.get_app_dir(CLI_NAME), ".ucred")
        config = configparser.ConfigParser()
        try:
            config.read(path)
        except FileNotFoundError:
            raise FileNotFoundError("\n\nCould not find the credentials, Please save the credentials using \n\n$ jtrader upstox savecreds")
        creds = config['CREDENTIALS']
        self.client_id = creds['user_id']
        self.password = creds['password']
        self.twofa = creds['twofa']
    
    def get_root_js(self):
        url = "https://pro.upstox.com" + self.get_js_name()
        r = self.s.get(url)
        return r.text

    def get_api_key(self, js):
        s = js.split("var s='")[1]
        s = s.split("';")[0]
        j = json.loads(s)
        
        return j
 
    def get_js_name(self):
        url = "https://pro.upstox.com"
        r = self.s.get(url)
        bs = BeautifulSoup(r.text, features="html.parser")
        script = bs.find('script')
        return script['src']

    async def connect(self):
        j = self.keys 
        wss_url = "wss://ws.upstox.com/socket.io/?apiId={apiId}&token={token}&client_id={client_id}&ReleaseType=Green&deviceId=523739463&EIO=3&transport=websocket"
        wss_url = wss_url.format(apiId=j['apiId'], token=j['token'], client_id=self.client_id)
        self.url = wss_url
        headers = [("Host", "ws.upstox.com"), ("User-Agent", 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36'),
                ("Accept-Language", "en-GB,en-US;q=0.9,en;q=0.8"), ("Origin", "https://pro.upstox.com")]
        self.websocket = await websockets.connect(self.url, ssl=ssl_context, origin="https://pro.upstox.com", extra_headers=headers)
        msg = await self.recv()
        msg = await self.recv()
        return msg
    
    async def send(self, msg):
        await self.websocket.send(msg)
    
    async def recv(self):
        return await self.websocket.recv()

    async def recv_forever(self):
        while(1):
            packet = await self.websocket.recv()
            if packet == '3':
                continue
            if packet[0:2] == '42':
                try:
                    msg = self.decode_packet(packet)
                    guid = msg['guid']
                    self.event_tree[guid]['result'] = msg
                    self.event_tree[guid]['event'].set()
                    continue
                except:
                    pass
                # guid = msg['']
            self.notification_handler(packet)


    def login(self):
        self.loop.run_until_complete(self.connect())
        self.loop.create_task(self.recv_forever())
        resp = self.client_login(client_id=str(self.client_id), password=self.password)
        resp = self.client_login2fa(password=str(self.twofa))
        self.loop.create_task(self.heart_beat())
        return resp

    async def heart_beat(self):
        while(1):
            await self.send('2')
            await asyncio.sleep(5)

    def create_packet(self, method_name, guid, **kwargs):
        payload = {"method": method_name, "type": "interactive", "guid": guid }
        payload["data"] = kwargs
        packet = '42' + json.dumps(["message", payload])
        return packet

    def decode_packet(self, packet):
        return json.loads(packet[2:])[1]
       
    def __getattr__(self, name):
        async def send_recv(**kwargs):
            guid = str(uuid.uuid4())
            msg = self.create_packet(method_name=name, guid=guid,  **kwargs)
            await self.send(msg)
            self.event_tree[guid] = {"event": asyncio.Event()}
            await self.event_tree[guid]["event"].wait()
            result = self.event_tree[guid]['result']
            del self.event_tree[guid]
            return result

        def factory(**kwargs):
            x = self.loop.run_until_complete(send_recv(**kwargs))
            return x
        return factory

    def place_order(self, **kwargs):
        pass

if __name__=="__main__":

    u = Upstox()
    u.load_creds()
    r = u.login()
    print(r)
    msg = u.get_client_info()
    print(msg)
    print(u.get_order_history())

    # print(u.event_tree)
  

    u.loop.run_until_complete(asyncio.sleep(100))






import os
import configparser
import pickle
import click
from jugaad_trader import Zerodha
from jugaad_trader.util import CLI_NAME


app_dir = click.get_app_dir(CLI_NAME)
if not os.path.exists(app_dir):
    os.makedirs(app_dir)

cred_file = '.zcred'
session_file = '.zsession'

@click.group()
def zerodha():
    """ Command line utilities for managing Zerodha account
        Get started by creating a session

        $ jtrader zerodha startsession
    """
    pass

@zerodha.command()
def startsession():
    """Saves your login session in the app config folder"""

    user_id = click.prompt("User ID >")
    password = click.prompt("Password >", hide_input=True)
    z = Zerodha()
    z.user_id = user_id
    z.password = password
    j = z.login_step1()
    if j['status'] == 'error':
        click.echo(click.style("Error: {}".format(j['message']), fg="red"))
        return
    z.twofa = click.prompt("Pin >", hide_input=True)
    j = z.login_step2(j)
    if j['status'] == 'error':
        click.echo(click.style("Error: {}".format(j['message']), fg="red"))
        return
    z.enc_token = z.r.cookies['enctoken']
    p = z.profile()

    click.echo(click.style("Logged in successfully as {}".format(p['user_name']), fg='green'))
    with open(os.path.join(app_dir, session_file), "wb") as fp:
        pickle.dump(z.reqsession, fp)
    click.echo("Saved session successfully")

@zerodha.command()
def savecreds():
    """Saves your creds in the APP config directory"""
    click.echo("Saves your creds in app config folder in file named {}".format(cred_file))
    user_id = click.prompt("User ID >")
    password = click.prompt("Password >", hide_input=True)
    twofa = click.prompt("Pin >", hide_input=True)
    config = configparser.ConfigParser()
    config['CREDENTIALS'] = {'user_id': user_id,
                                'password': password,
                                'twofa': twofa}
    with open(os.path.join(app_dir, cred_file), "w") as fp:
        config.write(fp)
        click.echo(click.style("Saved credentials successfully", fg='green'))



@zerodha.command()
def configdir():
    """Print app config directory location"""
    click.echo(app_dir)


@zerodha.command()
@click.argument("config")
def rm(config):
    """Delete stored credentials or sessions config

        To delete SESSION

        $ jtrader zerodha rm SESSION

        To delete CREDENTIALS

        $ jtrader zerodha rm CREDENTIALS
    """
    if config == "CREDENTIALS":
        try:
            os.remove(os.path.join(app_dir, cred_file))
        except FileNotFoundError:
            click.echo("Could not find any credentials, you can save it again using 'jtrader zerodha savecreds'")
        else:
            click.echo("Successfully deleted credentials config, you can save it again using 'jtrader zerodha savecreds`")
    
    if config == "SESSION":
        try:
            os.remove(os.path.join(app_dir, session_file))
        except FileNotFoundError:
            click.echo("Could not find the session config, you can save it again using 'jtrader zerodha startsession'")
        else:
            click.echo("Successfully deleted, you can save it again using 'jtrader zerodha startsession'")
    





if __name__ == "__main__":
    zerodha()
